@@ -4,15 +4,13 @@
 from .serie import *
 from .data import *
 from .dataset import *
-
 from .model import *
-from .sm import *
-from .mosm import *
-from .csm import *
-from .conv import *
-from .sm_lmc import *
+from .models.sm import *
+from .models.mosm import *
+from .models.csm import *
+from .models.sm_lmc import *
+from .models.conv import *
 
 from .plot import *
 from .errors import *
-
-from .kernels.config import *
+from .gpr.config import *
